# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKIOBMPPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkBMPImageIOPython
else:
    import _itkBMPImageIOPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrix_fixedPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.itkRGBPixelPython
import itk.ITKIOImageBaseBasePython

def itkBMPImageIO_New():
    return itkBMPImageIO.New()

class itkBMPImageIO(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkBMPImageIO class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBMPImageIO_Pointer"""
        return _itkBMPImageIOPython.itkBMPImageIO___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBMPImageIO_Pointer"""
        return _itkBMPImageIOPython.itkBMPImageIO_Clone(self)

    def GetFileLowerLeft(self):
        r"""GetFileLowerLeft(self) -> bool"""
        return _itkBMPImageIOPython.itkBMPImageIO_GetFileLowerLeft(self)

    def GetBMPCompression(self):
        r"""GetBMPCompression(self) -> long"""
        return _itkBMPImageIOPython.itkBMPImageIO_GetBMPCompression(self)

    def GetColorPalette(self):
        r"""GetColorPalette(self) -> std::vector< itkRGBPixelUC,std::allocator< itkRGBPixelUC > > const &"""
        return _itkBMPImageIOPython.itkBMPImageIO_GetColorPalette(self)

    def __init__(self):
        r"""__init__(self) -> itkBMPImageIO"""
        _itkBMPImageIOPython.itkBMPImageIO_swiginit(self, _itkBMPImageIOPython.new_itkBMPImageIO())

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkBMPImageIOPython.itkBMPImageIO_PrintSelf(self, os, indent)
    __swig_destroy__ = _itkBMPImageIOPython.delete_itkBMPImageIO

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBMPImageIO

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBMPImageIOPython.itkBMPImageIO_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBMPImageIO

        Create a new object of the class itkBMPImageIO and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBMPImageIO.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBMPImageIO.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBMPImageIO.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBMPImageIO in _itkBMPImageIOPython:
_itkBMPImageIOPython.itkBMPImageIO_swigregister(itkBMPImageIO)

def itkBMPImageIOFactory_New():
    return itkBMPImageIOFactory.New()

class itkBMPImageIOFactory(itk.ITKCommonBasePython.itkObjectFactoryBase):
    r"""Proxy of C++ itkBMPImageIOFactory class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBMPImageIOFactory_Pointer"""
        return _itkBMPImageIOPython.itkBMPImageIOFactory___New_orig__()

    @staticmethod
    def RegisterOneFactory():
        r"""RegisterOneFactory()"""
        return _itkBMPImageIOPython.itkBMPImageIOFactory_RegisterOneFactory()
    __swig_destroy__ = _itkBMPImageIOPython.delete_itkBMPImageIOFactory

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBMPImageIOFactory

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBMPImageIOPython.itkBMPImageIOFactory_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBMPImageIOFactory

        Create a new object of the class itkBMPImageIOFactory and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBMPImageIOFactory.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBMPImageIOFactory.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBMPImageIOFactory.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBMPImageIOFactory in _itkBMPImageIOPython:
_itkBMPImageIOPython.itkBMPImageIOFactory_swigregister(itkBMPImageIOFactory)

